@@ -7,6 +7,7 @@ from firebase_admin import credentials, exceptions as firebase_exceptions, messa
 
 from relay.blockchain.currency_network_events import (
     TransferEvent,
+    TrustlineRequestCancelEvent,
     TrustlineRequestEvent,
     TrustlineUpdateEvent,
 )
@@ -146,10 +147,9 @@ def _build_data_prop(event: Event):
 
     if isinstance(event, TrustlineUpdateEvent):
         data = _get_data_prop_dict(event)
-    elif isinstance(event, TransferEvent):
-        if event.direction == "received":
-            data = _get_data_prop_dict(event)
-    elif isinstance(event, TrustlineRequestEvent):
+    elif isinstance(
+        event, (TransferEvent, TrustlineRequestEvent, TrustlineRequestCancelEvent)
+    ):
         if event.direction == "received":
             data = _get_data_prop_dict(event)
     elif isinstance(event, MessageEvent):
